@@ -126,6 +126,16 @@ class TestInvalid(unittest.TestCase):
         self.assertEqual(childexc.pos, 0)
         self.assertEqual(childexc.node.name, 'found')
 
+    def test_messages_msg_iterable(self):
+        node = DummySchemaNode(None)
+        exc = self._makeOne(node, [123, 456])
+        self.assertEqual(exc.messages(), [123, 456])
+
+    def test_messages_msg_not_iterable(self):
+        node = DummySchemaNode(None)
+        exc = self._makeOne(node, 'msg')
+        self.assertEqual(exc.messages(), ['msg'])
+
 class TestAll(unittest.TestCase):
     def _makeOne(self, validators):
         from colander import All
@@ -1271,15 +1281,15 @@ class TestSchemaNode(unittest.TestCase):
         self.failUnless(hasattr(node, '_order'))
 
     def test_ctor_no_title(self):
-        node = self._makeOne(None, 0, validator=1, default=2, name='name',
+        node = self._makeOne(None, 0, validator=1, default=2, name='name_a',
                              missing='missing')
         self.assertEqual(node.typ, None)
         self.assertEqual(node.children, [0])
         self.assertEqual(node.validator, 1)
         self.assertEqual(node.default, 2)
         self.assertEqual(node.missing, 'missing')
-        self.assertEqual(node.name, 'name')
-        self.assertEqual(node.title, 'Name')
+        self.assertEqual(node.name, 'name_a')
+        self.assertEqual(node.title, 'Name A')
 
     def test_ctor_with_title(self):
         node = self._makeOne(None, 0, validator=1, default=2, name='name',
@@ -1434,7 +1444,7 @@ class TestSchema(unittest.TestCase):
     def test_it(self):
         import colander
         class MySchema(colander.Schema):
-            thing = colander.SchemaNode(colander.String())
+            thing_a = colander.SchemaNode(colander.String())
             thing2 = colander.SchemaNode(colander.String(), title='bar')
         node = MySchema(default='abc')
         self.failUnless(hasattr(node, '_order'))
@@ -1442,7 +1452,7 @@ class TestSchema(unittest.TestCase):
         self.assertEqual(node.__class__, colander.SchemaNode)
         self.assertEqual(node.typ.__class__, colander.Mapping)
         self.assertEqual(node.children[0].typ.__class__, colander.String) 
-        self.assertEqual(node.children[0].title, 'Thing')
+        self.assertEqual(node.children[0].title, 'Thing A')
         self.assertEqual(node.children[1].title, 'bar')
 
 class TestSequenceSchema(unittest.TestCase):
